@@ -29,6 +29,11 @@ context("Taxa Rollup")
 
 tr <- readRDS("outputs/taxa.rollup.rds")
 
+# turn off locale-specific sorting
+orig_LCC <- Sys.getlocale("LC_COLLATE")
+on.exit(Sys.setlocale("LC_COLLATE", orig_LCC))
+Sys.setlocale("LC_COLLATE", "C")
+
 for (txRank in c(taxa.ranks(biom), 'OTU')) {
   test_that(txRank, {
     expect_equal(tr[[txRank]], taxa.rollup(biom, txRank))
